package com.example.fuzzControll.service.impl;

import com.example.fuzzControll.conf.KittyProperties;
import com.example.fuzzControll.exception.CmdException;
import com.example.fuzzControll.exception.FuzzException;
import com.example.fuzzControll.pojo.vo.TestEntity;
import com.example.fuzzControll.service.VulnerabilityTypeService;
import com.example.fuzzControll.tools.CmdTools;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

@Slf4j
@Service("vulnerabilityTypeService")
public class VulnerabilityTypeServiceImpl implements VulnerabilityTypeService {
    CmdTools cmdTools = new CmdTools();
    @Autowired
    KittyProperties kitty;

    @Override
    public Map<String, List<String>> generation(TestEntity testEntity) throws FuzzException, CmdException {
        String cmd = parseParameters(testEntity);
        if (cmd.isEmpty()) {
            throw new FuzzException("cmd is null ! The number of parameters does not match!");
        }
        return cmdTools.runProgramCmdAndResult(cmd);
    }

    public String parseParameters(TestEntity testEntity) {
        try {
            switch (testEntity.getTestClassName().toLowerCase()) {
                case "array_index_out_of_bounds_vulnerabilit"://have error
                    return cmd(testEntity, 0);
                case "boundary_condition_vulnerability"://have error
                    return cmd(testEntity, 1);
                case "buffer_overflow_vulnerability"://have error
                    return cmd(testEntity, 2);
                case "command_injection_vulnerability"://have error
                    return cmd(testEntity, 3);
                case "memory_duplicate_release_vulnerability"://have error
                    return cmd(testEntity, 4);
                case "format_string_vulnerability"://have error
                    return cmd(testEntity, 5);
                case "integer_overflow_vulnerability"://have error
                    return cmd(testEntity, 6);
                case "numeric_error_vulnerabilit"://have error
                    return cmd(testEntity, 7);
                case "symbol_extension_vulnerability"://have error
                    return cmd(testEntity, 8);
                case "uaf_vulnerabilit"://have error
                    return cmd(testEntity, 9);
                case "cross_script_vulnerability"://have error
                    return cmd(testEntity, 10);
                case "sql_injection_vulnerabilit"://have error
                    return cmd(testEntity, 11);
                default:
                    throw new FuzzException("Unknown method!");
            }
        } catch (FuzzException e) {
            throw new FuzzException("Unknown class!");
        }
    }

    private String cmd(TestEntity testEntity, int kindNum) {
        return kitty.getVenvPath() + " " + kitty.getVulnerabilityTypePath() + "vul_types_test.py " + kindNum;
    }
}
